@@ -4,14 +4,18 @@ import urllib
 
 from django.http import HttpResponseRedirect
 
-from ecl_facebook.signals import post_facebook_auth
-from ecl_facebook import settings
+from facebook import Facebook
+from settings import DIALOG_URL
 
 def facebook_begin(fun):
+    """
+    Django view decorator that redirects the user to a URL where they can
+    authorize the application.
+    """
     @wraps(fun)
     def inner(request, *args, **kwargs):
         fun(request, *args, **kwargs)
-        return HttpResponseRedirect(settings.DIALOG_URL)
+        return HttpResponseRedirect(DIALOG_URL)
     return inner
 
 def facebook_callback(fun):
@@ -30,16 +34,11 @@ def facebook_callback(fun):
             # TODO Incorporate better error handling.
             raise Exception("Cookies must be enabled to log in with Facebook.")
 
-        params = settings.ACCESS_TOKEN_PARAMS.copy()
-        params['code'] = code
-        url = "https://graph.facebook.com/oauth/access_token?" + urllib.urlencode(params)
+        facebook = Facebook()
+        response = facebook.oauth.access_token(code=code)
 
-        # Fetch the access token
-        response = urllib.urlopen(url)
-        data = response.read()
-        attributes = cgi.parse_qs(data)
-        token = attributes['access_token'][0]
-        post_facebook_auth.send('ecl_facebook', token=token)
-        return fun(request, token, *args, **kwargs)
+        from .signals import post_facebook_auth
+        post_facebook_auth.send('ecl_facebook', token=response.access_token)
+        return fun(request, response.access_token, *args, **kwargs)
     return inner
 
